@@ -30,7 +30,7 @@ class KatapultItem;
 /**
 @author Joe Ferris
 */
-class CachedCatalog : public KatapultCatalog
+class KDE_EXPORT CachedCatalog : public KatapultCatalog
 {
 	Q_OBJECT
   
