@@ -32,7 +32,7 @@ class TDEConfigBase;
 /**
 @author Joe Ferris
 */
-class KatapultCatalog : public TQObject {
+class KDE_EXPORT KatapultCatalog : public TQObject {
 	Q_OBJECT
   
 
