@@ -33,7 +33,7 @@ class TDEConfigBase;
 /**
 @author Joe Ferris
 */
-class KatapultDisplay : public TQWidget
+class KDE_EXPORT KatapultDisplay : public TQWidget
 {
 	Q_OBJECT
   
