@@ -24,7 +24,7 @@
 #include <tqpixmap.h>
 #include <tqimage.h>
 #include <tqstring.h>
-#include <amarokcatalog.h>
+#include "amarokcatalog.h"
 
 #include "song.h"
 
