@@ -34,7 +34,7 @@
 #include <tqstring.h>
 
 #include "command.h"
-#include "katapultcatalog.h"
+#include <katapultcatalog.h>
 
 class TQWidget;
 
