@@ -25,7 +25,7 @@
 #include <tqptrlist.h>
 #include <tqstring.h>
 
-#include "cachedcatalog.h"
+#include <cachedcatalog.h>
 
 class TQWidget;
 
