@@ -34,9 +34,9 @@
 
 #include "settings.h"
 #include "spellcatalog.h"
-#include "actionregistry.h"
+#include <actionregistry.h>
 #include "actioncopyspelling.h"
-#include "status.h"
+#include <status.h>
 
 K_EXPORT_COMPONENT_FACTORY( katapult_spellcatalog,
                             KGenericFactory<SpellCatalog>( "katapult_spellcatalog" ) )
